<?php
#########################################################################################
##	Class: pt_thumbnail
##	Generate a thumbnail from an image url
##	Returns:
##		$this->thumb_url	: thumbnail url
##		$this->thumb_path	: thumbnail path on server
#########################################################################################
class pt_thumbnail {

	var $settings;
	var $arg;

	var $the_image;
	var $extension;

	var $thumb_url;
	var $thumb_path;

	var $sub_folder;
	var $alt_append;
	var $alt_append2;
	var $append;
	var $resize_width=0;
	var $resize_height=0;
	var $crop_x=0;
	var $crop_y=0;
	var $keep_ratio=false;
	var $max=false;
	var $rounded=false;
	var $dirname = false;

	var $width = 0;
	var $height = 0;
	var $use_png = false;
	var $use_jpg = false;

	var $error = false;
	var $defaultimg;

	var $exttype = array('jpg', 'png', 'jpeg', 'gif', 'JPG', 'JPEG', 'PNG', 'GIF');
	var $speChar = array( ' ' => '%20');

	/****************************************************************/
	/* Constructor
	/****************************************************************/
	function pt_thumbnail ($img_url='', $arg='', $default = false) {

		$this->the_image	= NormalizeURL(clean_url($img_url));
		$this->settings 	= get_pt_options_all();
		$this->arg 		= $arg;
		$this->defaultimg	= $default;
		unset($settings);
		
		$this->parse_arg();
		$this->get_thumbnail();
	}

	/****************************************************************/
	/* Retrieve all parameters
	/****************************************************************/
        function parse_arg () {
        
		$new_args = pt_parse_arg($this->arg);

		if (isset($new_args['SUBFOLDER']))
			$this->sub_folder = '/'.$new_args['SUBFOLDER'];
		else $this->sub_folder ='';
		$this->sub_folder = $this->test_folder($this->sub_folder);

		if (isset($new_args['DIRNAME'])) $this->dirname = (int) $new_args['DIRNAME'];

		if (isset($new_args['ALTAPPEND']))
			$this->alt_append = $new_args['ALTAPPEND'];
		else
			$this->alt_append = $this->settings['append_text'];

		if (isset($new_args['APPEND']))
			$this->append = ($new_args['APPEND']==1);
		else
                	$this->append = ($this->settings['append'] == 'true');

		if (isset($new_args['ADDAPPEND']))
			$this->alt_append2 = $new_args['ADDAPPEND'];
		else
			$this->alt_append2 = '';

		if (isset($new_args['WIDTH']))
			$this->resize_width = $new_args['WIDTH'];
                else 
			$this->resize_width = (int) $this->settings['resize_width'];

		if (isset($new_args['HEIGHT']))
			$this->resize_height = $new_args['HEIGHT'];
                else
			$this->resize_height = (int) $this->settings['resize_height'];

		if (isset($new_args['HCROP']))
			$this->crop_x = $new_args['HCROP'];
		else
			$this->crop_x = 0;

		if (isset($new_args['VCROP']))     
			$this->crop_y = $new_args['VCROP'];
		else
			$this->crop_y = 0;

		if (isset($new_args['KEEPRATIO']))
			$this->keep_ratio = ($new_args['KEEPRATIO']==1);
		else
                	$this->keep_ratio = ($this->settings['keep_ratio'] == 'true');

		if (isset($new_args['MAX']))
			$this->max = ($new_args['MAX']==1);
		else
                	$this->max = ($this->settings['max'] == 'true');

		if (isset($new_args['MIME'])) {
			$this->use_png = ($new_args['MIME']=='png');
			$this->use_jpg = ($new_args['MIME']=='jpg');
		}
                else
                	$this->use_png = ($this->settings['use_png'] == 'true');

		if (isset($new_args['ROUNDED']))
			$this->rounded = ($new_args['ROUNDED']==1);
		else
                	$this->rounded = ($this->settings['rounded'] == 'true');

		if ($this->rounded) $this->use_png = true;

	}
	/****************************************************************/
	/* Creates and returns thumbnail
	/*
	/* Fix for Dreamhost: Dreamhost cannot deal with imagecreatefromstring
	/****************************************************************/
	function get_thumbnail() {
	
		// Save image info
		$the_processed_image = $this->imageFilter();                
                $is_remote  = ($this->image == $the_processed_image);                                                                      // Fix for Dreamhost
		$dest_path = pt_pathinfo($the_processed_image);

		// Build dir to save thumbnail to
		$save_dir = $this->settings['base_path'].'/'.$this->settings['folder_name'].$this->sub_folder;
		$save_url = $this->settings['full_domain_name'].'/'.$this->settings['folder_name'].$this->sub_folder;

		// If file extension is not known, assume it's a redirect url
		if ($dest_path['extension']== '' || !in_array($dest_path['extension'], $this->exttype)) {
			$dest_path = $this->urlFilter($save_dir, $save_url);
		}
				
		// Set directory name if it needs to be included in thumbnail's name
		if ($this->dirname > 0) {
			$dirname = $this->dirDecode($dest_path['dirname']);
		} else $dirname='';

		// Find extension to use for thumbnail
		if ($this->use_png) 	$this->extension = 'png';
                elseif ($this->use_jpg)	$this->extension = 'jpg';
                else			$this->extension = strtolower($dest_path['extension']);
                if ($this->extension == '') $this->extension = 'jpg';

		// Builds thumbnail file name
		$filename = $dirname.$this->nameFilter($dest_path['filename']);
		if ($this->defaultimg)
			$filename = $filename.$this->resize_width.'x'.$this->resize_height;

		if ($this->append == 'true')
			$rename_to = $filename.$this->alt_append.$this->alt_append2.'.'.$this->extension;
		else
			$rename_to = $this->alt_append.$filename.$this->alt_append2.'.'.$this->extension;
		$rename_to = sanitize_file_name($rename_to);

		// checks if file already exists - returns location if it does
		if (file_exists($save_dir.'/'.$rename_to)) {
                        $this->thumb_url 	= $this->settings['full_domain_name'].'/'.$this->settings['folder_name'].$this->sub_folder.'/'.$rename_to;
			$this->thumb_path   	= $save_dir.'/'.$rename_to;
		}

		// check if image exists. If doesn't exist, can't do anything so return default image
                elseif (false === remote_file_exists($this->the_image)) {
			$this->thumb_url 	= $this->settings['full_domain_name'].$this->sub_folder."/".$this->settings['default_image'];
			$this->thumb_path   	= $this->settings['base_path']."/".$this->settings['default_image'];
		}

		// if file has to be generated, generates thumbnails
		else {
			$this->thumb_url 	= $this->settings['full_domain_name']."/".$this->settings['folder_name'].$this->sub_folder."/".$rename_to;
			$this->thumb_path   	= $save_dir.'/'.$rename_to;

			// Create the image
			$thumb = new ImageEditor($the_processed_image,'', '', $is_remote);          // Fix for Dreamhost
                        if ($thumb->img_error || $thumb->error) {
				unset($thumb);
				$this->error = true;
				return false;
			}

			// Set output type if different from image
			$thumb->setImageType($this->extension);

	                // Resize image
			$thumb->resize($this->resize_width, $this->resize_height, $this->crop_x, $this->crop_y, $this->keep_ratio, $this->max);
			
			// Round corner if option is checked
			if ($this->rounded) {
				$thumb->setImageType('png');
				$thumb->rounded($this->settings['corner_ratio']);
			}

	                if (!$thumb->error) {
		                // If no error so far, saves thumbnail on server
				$thumb->outputFile($save_dir."/".$rename_to, "", $this->settings['jpg_rate'], $this->settings['png_rate']);

	        	        // Get thumbnail size (may be different from resize size)
				$this->width = $thumb->getWidth();
				$this->height = $thumb->getHeight();
			}
			else
				$this->error = true;

			unset($thumb);
                }
	}
	/****************************************************************/
	/* Change the url if url is a redirect. Sets up for gallery2.
	/****************************************************************/
	function dirDecode($url) {
		$url_dec = explode('/', str_replace('\\', '/', $url));
		$dir1 = end($url_dec);
		if ($this->dirname > 1) {
			$i=1;
			while ($i<$this->dirname) {
				$tmp = prev($url_dec);
				if (strpos($tmp, ':') !== false || strpos($tmp, '.') !== false) break;
				$dir1 = $tmp.$dir1;
				$i++;
			}
		}
		return sanitize_file_name($dir1);
	}
	/****************************************************************/
	/* Check url. Set up for ngg & Dreamhost.
	/****************************************************************/
	function ImageFilter() {
		global $wpdb;

		$url = str_replace ('&amp;','&', $this->the_image);

		// Filters ngg singlepic
		if (stripos($url, "nggshow.php")) {
			$pos = strpos($url, 'pid=')+4;
			$ngg_pid = explode('&', substr($url, $pos));
			$ngg_pic = $wpdb->get_row("SELECT filename, galleryid FROM $wpdb->nggpictures WHERE pid = '$ngg_pid[0]' ");
			if ($ngg_pic) {
				$gallery_path = $wpdb->get_var("SELECT path FROM $wpdb->nggallery WHERE gid = '$ngg_pic->galleryid' ");
				$this->the_image = SITEURL.'/'.$gallery_path.'/'.$ngg_pic->filename;;
			}
		}

                $the_processed_image = str_replace($this->settings['full_domain_name'], $this->settings['base_path'], $this->the_image);   // Fix for Dreamhost

		return $the_processed_image;                
	}
	/****************************************************************/
	/* Change the url if url is a redirect. Sets up for gallery2.
	/****************************************************************/
	function urlFilter($save_dir, $save_url) {
		global $wpdb;

		$url = str_replace ('&amp;','&', $this->the_image);

		// Filters gallery2 names
		if (stripos($url, "g2_itemId=")) {
			$g2_image = explode("g2_itemId=", $url);
			$g2_id = explode('&', $g2_image[1]);
			$uri = 'wpg2-'.$g2_id[0].'.jpg';
			$save_dir .= '/'.$uri;
			$save_url .= '/'.$uri;
			if ($file = @file_get_contents($save_url)) {
				if ($handle = @fopen($save_dir, 'a')) {
					fwrite ($handle, $file);
					fclose($handle);
				}
			}
			$this->the_image = $save_url;
		}
	
		return pt_pathinfo($save_url);
	}
	/****************************************************************/
	/* 
	/****************************************************************/
	function nameFilter($rename_to) {

		$rename_to = str_replace ('%20', '_', $rename_to);
		$rename_to = str_replace ('%', '_', $rename_to);
		$rename_to = str_replace (' ', '_', $rename_to);
		
		// Filters gallery2 names
		if (stripos($rename_to, "g2_itemId=")) {
			$rename_to = str_replace ('&amp;', '&', $rename_to);
			$g2_image = explode("g2_itemId=", $rename_to);
			$g2_id = explode('&', $g2_image[1]);
			$rename_to = 'wpg2-'.$g2_id[0];
		}
		
		return $rename_to;
	}
	/****************************************************************/
	/* Tests and creates sufolder. If cannot, return blank.
	/****************************************************************/
	function test_folder($sub_folder) {
	
		if ($sub_folder == '/' || $this->settings['safe_mode']=='true') return '';
		
 		$tempdir = $this->settings['base_path'].'/'.$this->settings['folder_name'].$sub_folder;
 		if (wp_mkdir_p($tempdir)) return $sub_folder; else return '';
 		
		return '';
	}
	/****************************************************************/
	/* Creates and returns thumbnail
	/****************************************************************/
	function sanitize_url($url) {
		foreach ($this->speChar as $key => $value) :
			$url = str_replace($key, $value, $url);
		endforeach;
		return $url;
	}

}  // End of pt_thumbnail class

#########################################################################################
##	Class: pt_post_thumbnail
##	Generate a html linked to a post. This html:
##		- can contain a thumbnail from an image of the post
##		- can show several informations from the post
##	Returns:
##      	$this->html
##		$this->thumb_url	: thumbnail url
##		$this->thumb_path	: thumbnail path on server
##		$this->the_image	: url of the linked image
#########################################################################################
class pt_post_thumbnail {

	var $meta;
	var $settings;
	var $arg;
	var $post;
	
	var $the_image='';
	var $src = '';
	
	var $extension;

	var $thumb_url;
	var $thumb_path;

	var $html;
	var $title;

	var $alt_text;
	var $use_catname;
	var $show_title = '';
	var $img_title;
	var $myclasshref = '';
	var $myclassimg = '';
	var $imgclass = '';
	var $LB_effect = false;
	var $showlink;
	var $link = 'i';
	var $align = '';
	var $ajax = false;

	var $nodef;
	var $def_image = false;		// True if no image or media in post
	var $def_url;
	var $width;
	var $height;
	var $resize_width;
	
	var $n = "\n";
	var $nt = "\n\t";
	
	var $the_media = '';
	var $media_width;
	var $media_height;

	/****************************************************************/
	/* Constructor
	/****************************************************************/
	function pt_post_thumbnail ($meta='', $arg='') {
		global $post;

		// Get all parameters
		$this->meta 	= $meta;
		$this->post 	= $post;
		$this->settings = get_pt_options_all();
		$this->arg 	= $arg;
		$this->def_url	= $this->settings['full_domain_name']."/".$this->settings['default_image'];

		// Set all the parameter options
		$this->parse_arg();
		
                // Get the image to thumbnailed
               	$this->get_the_image();

                // Get the thumbnail
               	$this->get_the_thumbnail();

                // Get the link to attached
               	$this->get_the_link();

                // Get the title to attached
               	$this->get_the_title();
		// Use $this->GetImgHTML(); to get output string

	}

	/****************************************************************/
	/****************************************************************/
        function parse_arg () {

		$new_args = pt_parse_arg($this->arg);

		if (isset($new_args['NOFORM'])) {
			$this->n = "";
			$this->nt = "";
		}

		if (isset($new_args['WIDTH']))
			$this->resize_width = $new_args['WIDTH'];
                else
			$this->resize_width = (int) $this->settings['resize_width'];

		$this->nodef = isset($new_args['NODEF']);

		if (isset($new_args['ALTTEXT']))
			$this->alt_text = str_clean ($new_args['ALTTEXT']);
                else {
			if ($this->post->post_title == '')
				$this->alt_text = $this->default_title;
			else
				$this->alt_text = $this->post->post_title;
		}

		if (isset($new_args['USECATNAME'])) 
			$this->use_catname = ($new_args['USECATNAME']==1);
		else
			$this->use_catname = ($this->settings['use_catname']=='true');

		if (isset($new_args['SHOWTITLE']) && $new_args['SHOWTITLE'] != '')
			$this->show_title = $this->Return_Title($new_args['SHOWTITLE']);

		if (isset($new_args['CAPTION']))
			$this->has_caption = ($new_args['CAPTION'] == 1);
		else 
			$this->has_caption = ($this->settings['caption']=='true');

		if (isset($new_args['TITLE']))
			$this->img_title = $this->Get_Title($new_args['TITLE']);
                else
			$this->img_title = $this->title;

		if (isset($new_args['MYCLASSHREF']))
			$this->myclasshref = $new_args['MYCLASSHREF'];

		if (isset($new_args['ALIGN']))
			$this->align = ' align="'.$new_args['ALIGN'].'"';

		if (isset($new_args['MYCLASSIMG']))
			$this->myclassimg = $new_args['MYCLASSIMG'];
		if ($this->myclassimg == '') $this->imgclass = '';
		else $this->imgclass = ' class="'.$this->myclassimg.'" ';

		if (isset($new_args['LB_EFFECT']))
			$this->LB_effect = ($new_args['LB_EFFECT']==1);
		else
			$this->LB_effect = ($this->settings['effect']=='true');

		if (isset($new_args['LINK']))
			$this->link = $new_args['LINK'];
		else
			$this->link = $this->settings['linkto'];
	}
	/****************************************************************/
	/****************************************************************/
	function get_the_image() {

		$this->src = 'img';

 	        // if image is already given
		if ($this->meta['ytb']['url'] != '') {
			$this->the_image = $this->meta['ytb']['img'];
			$this->the_media = $this->meta['ytb']['url'];
			if ($this->LB_effect)
				$this->src = 'ytb';
			if ($this->arg == '') 'dirname=1';
			else $this->arg .= '&dirname=1';
		}
		elseif ($this->meta['med']['url'] != '') {
			$this->the_image = $this->meta['med']['img'];
			$this->the_media = $this->meta['med']['url'];
			$this->media_width = $this->meta['med']['width'];
			$this->media_height = $this->meta['med']['height'];
			if ($this->LB_effect)
				$this->src = 'med';
		}
		elseif ($this->meta['img']['img'] != '') {
			$this->the_image = $this->meta['img']['img'];
		}

                // If no image found in the post content - checks for video
	        elseif ($this->use_catname) {
	        	$this->Get_DefaultCategory();
	        	$this->the_image = $this->def_url;
			$this->src = 'def';
		}

                // If no image found in the post content - checks for video
	        elseif (!empty($this->settings['video_regex']) && $this->content_check_video()) {
			$this->the_image = $this->settings['full_domain_name']."/".$this->settings['video_default'];
			$this->src = 'def';
		}

                // If no image found yet - checks for videostream
	        elseif ($this->settings['stream_check']=='true' && $this->content_check_stream()) {
			$this->the_image = $this->check_stream();
			$this->src = 'def';
		}

                // If really no image, return default image
		else {
	        	$this->the_image = $this->def_url;
			$this->src = 'def';
		}
	}
	/****************************************************************/
	/****************************************************************/
	function get_the_thumbnail() {

		if ($this->the_image != '') {
			$t = new pt_thumbnail ($this->the_image, $this->arg);
			if ($t->error) {
				unset($t);
				$t = new pt_thumbnail ($this->def_url, $this->arg, true);
			}
			$this->thumb_url 	= $t->thumb_url;
			$this->thumb_path	= $t->thumb_path;
			$this->width 		= $t->width;
			$this->height 		= $t->height;
			unset($t);
		}
	}
	/****************************************************************/
	/****************************************************************/
	function get_the_link() {
	
		if ($this->link == 'p' || $this->src == 'def')
			$this->showlink = get_permalink($ID);
		else {
			if ($this->meta[$this->src]['url'] == '')
				$this->showlink = $this->meta[$this->src]['img'];
			else			
				$this->showlink = $this->meta[$this->src]['url'];
		}
	}
	/****************************************************************/
	/****************************************************************/
	function get_the_title() {
		global $post;
		
		if ($this->link == 'n')
			$this->title = $this->the_image;
		elseif ($this->link == 'p' || $this->src == 'def')
			$this->title = get_the_title();
		elseif ($this->src == 'img')
			$this->title = $this->the_image;
		elseif ($this->src == 'ytb')
			$this->title = $this->the_image;
		elseif ($this->src == 'med')
			$this->title = $this->the_image;
		else
			$this->title = $this->the_image;

	}
	/****************************************************************/
	/* Returns html string with link and thumbnail
	/****************************************************************/
	function GetImgHTML() {

		// If no image in the post and NODEF=0, returns nothing
		if ($this->src == 'def' && $this->nodef) return '';
		
		// If LINK=n (no image) returns thumbnail with no 'a' tag
		if ($this->link == 'n') {
			$this->html = '<img src="'.$this->thumb_url.'" '.$this->imgclass.' alt="" />';
		}
		
		// Starts Highslide output
		elseif ($this->LB_effect && POSTTHUMB_USE_HS) {

			// If link to post, or post doesn't has picture, and post doesn't have media
			if ($this->link == 'p' || $this->link == 'u' || $this->src == 'def') {

				$h = new pt_highslide($this->showlink, $this->thumb_url, $this->title);
				$h->set_wrapClass('highslide-wrapper');
				$h->set_borders($this->settings['hsframe']);
				$h->set_href_text($this->img_title, $this->align);
				$h->set_myclassimg($this->myclassimg);
				$h->set_myclasshref($this->myclasshref);
				$h->set_bottom(__('Direct link to: ', 'post-thumb').$this->title, $link);
				$h->set_size($this->settings['hs_width'], $this->settings['hs_height'], $this->settings['hsmargin']);
				if ($this->ajax)
					$this->html = $h->highslide_link('ajax');
				else
					$this->html = $h->highslide_link('iframe');
				unset($h);
			}

	                // If a media is given, links to the media
			elseif ($this->src == 'med') {

				$this->html = $this->GetVideo ($this->title, $this->the_media, $this->thumb_url, $this->settings['wordtube_pwidth'], $this->settings['wordtube_pheight']);

			}

	                // If a media is given, links to the media
			elseif ($this->src == 'ytb') {

				$this->html = SetYoutubeVideo ($this->the_media, $this->title, $this->thumb_url, $this->settings, $this->imgclass.$this->align);

			}

			// Otherwise, links to picture
	                else {

				$h = new pt_highslide($this->the_image, $this->thumb_url, $this->title);
				$h->set_borders ($this->settings['ovframe']);
				$h->set_myclassimg($this->myclassimg);
				$h->set_myclasshref($this->myclasshref);
				$h->set_href_text('', $this->align);
				if ($this->has_caption) $h->set_caption(htmlspecialchars(str_replace("'", "\'", $this->title), ENT_QUOTES));
				$this->html = $h->highslide_link('overlay');
				unset($h);
			}
		}

		// Starts output using no javascript library
		else {
			$this->html = $this->n.'<a href="'.$this->showlink.'"';
	                $this->html .= ' title="'.htmlspecialchars($this->title).'"';
			if ($this->myclasshref !='') $this->html .= ' class="'.$this->myclasshref.'"';
			$this->html .= '>';

			$this->html .= $this->nt.'<img src="'.$this->thumb_url.'" alt="'.htmlspecialchars($this->alt_text).'"';
		        $this->html .= $this->imgclass;
		        $this->html .= $this->align;
	                $this->html .= ' />'.$this->n.'</a>';
		}

		if ($this->show_title != '') $this->get_add_html();
		
		return $this->html;

	}
	/****************************************************************/
	/* Set additionnal html string with link and thumbnail
	/****************************************************************/
	function get_add_html() {

		$this->html .= $this->show_title;
	}
	/****************************************************************/
	/* Check if there is a video in content using REGEX
	/****************************************************************/
	function content_check_video() {

		return (preg_match('/'.$this->settings['video_regex'].'/i',$this->post->post_content,$matches));
	}
	/****************************************************************/
	/* Returns adhoc thumbnail for videostream
	/****************************************************************/
	function check_stream() {

		$the_image = '';
               // Tag for Youtube
		if (
			(stripos($this->post->post_content, 'http://youtube.com/watch') !== false) ||
			(stripos($this->post->post_content, 'http://www.youtube.com/v/') !== false) ||
			(stripos($this->post->post_content, '[youtube') !== false)) 
		{
			$the_image = PT_URLPATH.'images/youtube.png';
		}


                // Tag for Dailymotion
		elseif (
			(stripos($this->post->post_content, 'http://www.dailymotion.com/swf') !== false) || 
			(stripos($this->post->post_content, 'http://www.dailymotion.com/video') !== false) ||
			(stripos($this->post->post_content, '[dailymotion') !== false))
		{
			$the_image = PT_URLPATH.'/images/dailymotion.png';
		}

		// Tag for googlevideo
		elseif (
			(stripos($this->post->post_content, 'http://video.google.fr/videoplay') !== false) || 
			(stripos($this->post->post_content, 'http://video.google.com/videoplay') !== false) || 
			(stripos($this->post->post_content, '[googlevideo') !== false))
		
		{
			$the_image = PT_URLPATH.'/images/gvideo.png';
		} 

		return $the_image;
	}
	/****************************************************************/
	/* Returns adhoc thumbnail for videostream
	/****************************************************************/
	function content_check_stream() {

		$test = $this->check_stream();
		return ($test != '');
	}
	/***********************************************************************************/
	/* Test if image in content
	/* $img_only = true  : return true if an image is found in the current post
	/* $img_only = false : return true if an image or a video is found in the current post
	/***********************************************************************************/
	function post_content_test($img_only=false) {

		// find an image from the post content
		if (preg_match('/<img(.*?)src=["'."']".'(.*?)["'."']".'/i',$this->post->post_content,$matches))
			return true;
	        else
	        {
			if (!empty($this->settings['video_regex']) && (!$img_only) && $this->content_check_video())
				return true;
			if (($this->settings['stream_check']) && (!$img_only) && ($this->content_check_stream()))
				return true;
			return false;
		}
	}
	/****************************************************************/
	/* Add post-thumb option SHOWTITLE
	/****************************************************************/
	function Return_Title ($showtitle='') {

		$arg = strtoupper($showtitle);
		$ret = $this->n.'<ul style = "width:'.$this->resize_width.'px;">';
		$sep = ', ';
		while ($arg <>'') :

			if (strlen($arg)==1) $sep = '';
			$option = substr($arg, 0, 1);
			$ret .= $this->Return_TitleOption ($option, $sep);
			$arg = substr($arg, 1);

	        endwhile;

		$ret .= $this->n.'</ul>';
		
		return $ret;

	}
	/****************************************************************/
	/* Add post-thumb option TITLE
	/****************************************************************/
	function Return_TitleOption ($option, $sep) {

		switch ($option) :
			case 'A':
				if ($this->default_author == '')
					$ret = $this->nt.'<li>'.get_author_name($this->post->post_author).$sep.'</li>';
				else
					$ret = $this->nt.'<li>'.$this->default_author.$sep.'</li>';
				break;
					
			case 'D':
				if ($this->default_date == '')
					$ret = $this->nt.'<li>'.substr($this->post->post_date, 0, 10).$sep.'</li>';
				else
					$ret = $this->nt.'<li>'.substr($this->default_date, 0, 10).$sep.'</li>';
				break;
					
			case 'E':
				$ret = $this->nt.'<li>'.excerpt_revisited($this->post->post_content, 40, $this->post_url).$sep.'</li>';
				break;

			case 'T':
				$ret = $this->nt.'<li><a href="'.$this->post_url.'">'.$this->title.'</a>'.$sep.'</li>';
				break;
					
		endswitch;

		return $ret;
	}
	/****************************************************************/
	/* Add post-thumb option TITLE
	/****************************************************************/
	function Get_Title ($title='') {
          
		$arg = strtoupper($title);
		switch ($arg) :
			case 'C':
				$ret = htmlspecialchars(excerpt_revisited($this->post->post_content, -1));
				break;
			case 'E':
				$ret = htmlspecialchars(excerpt_revisited($this->post->post_content, 40));
				break;
			case 'T':
                      		$ret = htmlspecialchars($this->post->post_title);
				break;
		endswitch;

		return $ret;
	}

	/****************************************************************/
	/* Get category image
	/****************************************************************/
	function Get_DefaultCategory () {

		if (get_bloginfo('version')>='2.1')
			$myposts = wp_get_post_categories($this->post->ID);
		else
			$myposts = wp_get_post_cats('1', $this->post->ID);
	
		$array_def = pt_pathinfo($this->def_url);
		$filename = $array_def['filename'];

		foreach ($myposts as $mypost) :

			$new_def = $array_def['dirname'].'/'.$filename.'cat-'.$mypost.'.'.$array_def['extension'];
			if (remote_file_exists($new_def)) {
                        	$this->def_url = $new_def;
                        	break;
			}
		endforeach;

	}
	/****************************************************************/
	/* Get video call
	/****************************************************************/
	function GetVideo ($name, $file, $image, $play_width, $play_height) {

		// Init parameters
		$settings = '';
		$path = pathinfo($file);
		$extension = strtoupper($path['extension']);
		$hs_width = $play_width;
		$ID = 'v'.rand();

		// Prepare the script string
		if ($extension == "FLV")
			$text = $this->settings['wordtube_vtext'];
		elseif ($extension == "MP3") 
			$text = $this->settings['wordtube_mtext'];
				

		// Prepare highslide html
		if (class_exists('pt_highslide')) {

	                $replace = SetWordTubeMedia ($file, $image, $play_width, $play_height, $ID, $extension, '', '');
			$h = new pt_highslide('#', $this->thumb_url, $name);
			$h->set_wrapClass('highslide-wrapper-wtb');
			$h->set_borders($this->settings['hsframe']);
			$h->set_size($play_width, $play_height, $this->settings['hsmargin']);
			$h->set_myclassimg($this->myclassimg);
			$h->set_href_text($name, $this->align);
			$h->set_myclasshref($this->myclasshref);
			$highslide = $h->highslide_link('swfObject', 'so'.$ID);
			unset($h);
	
			$replace .= $highslide;
		}
		elseif (class_exists('pt_thickbox')) {

       	                $replace = SetWordTubeMedia ($file, $image, $play_width, $play_height, $ID, $extension, '', '', true);
			$h = new pt_thickbox('', $this->thumb_url, $name);
			$h->set_size($play_width+5, $play_height+10);
			$h->set_href_text($name);
			$h->set_body($replace);
			$replace = $h->thickbox_link('swfObject', $ID);

		}
		
		return $replace;

	}

}  // End of pt_post_thumbnail class

#########################################################################################
##	Class: pt_meta_thumbnail
##	Description: create, update, delete and retrieve pt meta key/value
#########################################################################################
class pt_meta_thumbnail {

	var $ID = 0;  // post ID
	var $metakeyIMG = 'pt_metakey_img';
	var $metakeyMED = 'pt_metakey_med';
	var $metakeyYTB = 'pt_metakey_ytb';
	
	var $img = array();
	var $med = array();
	var $ytb = array();
	
	var $metaContentIMG = "";
	var $metaContentMED = "";
	var $metaContentYTB = "";

	/*******************************************************************************/
	/* 
	/*******************************************************************************/
	function pt_meta_thumbnail ($ID=0) {
	
		$this->ID = $ID;
		$this->metaContentIMG = get_post_meta($ID, $this->metakeyIMG, true);
		$this->metaContentMED = get_post_meta($ID, $this->metakeyMED, true);
		$this->metaContentYTB = get_post_meta($ID, $this->metakeyYTB, true);
		if ($this->metaContentIMG == '' && $this->metaContentMED == '' && $this->metaContentYTB == '') $this->CreateMeta();
		
	}
	/*******************************************************************************/
	/* 
	/*******************************************************************************/
	function CreateMeta () {
		$this->RetrieveMeta();
		$this->SetMetaValue();
		if ($this->metaContentIMG != '')
			add_post_meta($this->ID, $this->metakeyIMG, $this->metaContentIMG, true);
		if ($this->metaContentMED != '')
			add_post_meta($this->ID, $this->metakeyMED, $this->metaContentMED, true);
		if ($this->metaContentYTB != '')
			add_post_meta($this->ID, $this->metakeyYTB, $this->metaContentYTB, true);
	}
	/*******************************************************************************/
	/* 
	/*******************************************************************************/
	function DeleteMeta() {
		delete_post_meta($this->ID, $this->metakeyIMG);
		delete_post_meta($this->ID, $this->metakeyMED);
		delete_post_meta($this->ID, $this->metakeyYTB);
	}
	/*******************************************************************************/
	/* 
	/*******************************************************************************/
	function UpdateMeta() {
		$this->DeleteMeta();
		$this->RetrieveMeta();
		$this->SetMetaValue();
		if ($this->metaContentIMG != '')
			add_post_meta($this->ID, $this->metakeyIMG, $this->metaContentIMG, true);
		if ($this->metaContentMED != '')
			add_post_meta($this->ID, $this->metakeyMED, $this->metaContentMED, true);
		if ($this->metaContentYTB != '')
			add_post_meta($this->ID, $this->metakeyYTB, $this->metaContentYTB, true);
	}
	/*******************************************************************************/
	/* 
	/*******************************************************************************/
	function RetrieveMeta() {

        	global $wpdb;

 		$post = get_post($this->ID);
		$post->post_content = $this->apply_filters($post->post_content);

       		if (get_pt_options('use_meta') == 'true') {
       			$metaContent = get_post_meta($this->ID, 'pt_meta_thumb', true);
			// Check metacontent
			if ($metaContent != '') {
	
				$pattern1 = '/youtube=\((.*?)\)(.*?)/i';
				$pattern2 = '/MEDIA=([0-9]+%?)/i';
				if (preg_match($pattern1, $metaContent, $match)) {
	
					$this->ytb['img'] = 'http://img.youtube.com/vi/'.$match[1].'/0.jpg';
					$this->ytb['url'] = $match[1];
		
				} elseif (preg_match($pattern2, $metaContent, $match)) {
	
						$media = $wpdb->get_row("SELECT * FROM $wpdb->wordtube WHERE vid = $match[1] ");
						if ($media) {
							$this->med['img'] = htmlspecialchars(addslashes($media->image));
							$this->med['url'] = htmlspecialchars(addslashes($media->file));
							if (pt_is_flv($media->file)) {
								$this->med['width'] = $media->width;
								$this->med['height'] = $media->height;
							}
						}
	
				} else {
					$this->img['img'] = $metaContent;
					$this->img['alt'] = $metaContent;
				}
			}
		}

	  	// finds an image from the post content
	  	if (count($this->img) == 0) {
		if (preg_match('@<img([^>]*)\/>@si', $post->post_content, $matches)) {

			// put matches into recognizable vars
			$la = pt_parseAtributes($matches[0], array('src', 'alt'));
			$this->img['img'] = $la['src'];
			$this->img['alt'] = $la['alt'];

			// Prepare for RegEx
			$img_src = str_replace(array("%", "|", "@", ")", "("), array("\%", "\|", "\@", "\)", "\("), $this->img['img']);

			// detects if the image is already linked to a thumbnail
			$pattern = '%<a([^>]*).(jpg|jpeg|png|gif)([^>]*)\>([^>]*)'.$img_src.'([^\<]*)\<\/a>%si';
			if (preg_match($pattern,$post->post_content,$matches)) {
				$la = pt_parseAtributes($matches[0], array('href'));
				$this->img['img'] = $la['href'];
			} 

			// detects if the image is linked to an url
			$pattern = '%<a([^>]*)>([^>]*)'.$img_src.'([^<]*)\<\/a>%i';
			if (preg_match($pattern,$post->post_content,$matches)) {
				$la = pt_parseAtributes($matches[0], array('href'));
				$this->img['url'] = $la['href'];
			}
		}
		}

		// Search for wordTube MEDIA.
	  	if (count($this->med) == 0) {
		$pattern = '/\[MEDIA=([0-9]+%?)\]/i';
		if (preg_match($pattern, $post->post_content, $match)) {
					
			$media = $wpdb->get_row("SELECT * FROM $wpdb->wordtube WHERE vid = $match[1] ");
			if ($media) {
				$this->med['img'] = htmlspecialchars(addslashes($media->image));
				$this->med['url'] = htmlspecialchars(addslashes($media->file));
				if (pt_is_flv($media->file)) {
					$this->med['width'] = $media->width;
					$this->med['height'] = $media->height;
				}
			}
		}
		}
		 
		// Search for Youtube video.
	  	if (count($this->ytb) == 0) {
		$pattern1 = '/\[youtube=\((.*?)\)(.*?)\]/i';
		$patternEasytube = '/\[youtube:(.*?)\]/i';
		$patternVideoWarrior = '/\[youtube (.*?)\]/i';
		$pattern1bis = '@\[youtube=([0-9a-zA-Z_]*)(\s*)(.*?)\]@i';
		$pattern2 = '/\<a(.*?)href="http:\/\/www\.youtube\.com\/watch\?v\=(.*?)"(.*?)\<\/a>/i';
		$pattern3 = '/\<object([^>]*)>([^>]*)\<param([^>]*)value=[\'|"]http:\/\/www.youtube.com\/v\/(.*?)[\'|"]\>\<\/param>([^>]*)\<param(.*?)\<\/object>/is';
		if (preg_match($pattern1, $post->post_content, $match)) {
	
			$this->ytb['img'] = 'http://img.youtube.com/vi/'.$match[1].'/0.jpg';
			$this->ytb['url'] = $match[1];
	
		} elseif (preg_match($pattern1bis, $post->post_content, $match)) {
	
			$this->ytb['img'] = 'http://img.youtube.com/vi/'.$match[1].'/0.jpg';
			$this->ytb['url'] = $match[1];
	
		} elseif (preg_match($patternEasytube, $post->post_content, $match)) {
	
			$parts = explode(" ", $match[1]);
			$vid= explode('=',$parts[0],2);

			$this->ytb['img'] = 'http://img.youtube.com/vi/'.$vid[1].'/0.jpg';
			$this->ytb['url'] = $vid[1];
	
		} elseif (preg_match($patternVideoWarrior, $post->post_content, $match)) {
	
			$this->ytb['img'] = 'http://img.youtube.com/vi/'.$match[1].'/0.jpg';
			$this->ytb['url'] = $match[1];
	
		} elseif (preg_match($pattern2, $post->post_content, $match)) {
	
			$this->ytb['img'] = 'http://img.youtube.com/vi/'.$match[2].'/0.jpg';
			$this->ytb['url'] = $match[2];
	
		} elseif (preg_match($pattern3, $post->post_content, $match)) {
	
			$ytbID = explode('&', $match[4]);
			$this->ytb['img'] = 'http://img.youtube.com/vi/'.$ytbID[0].'/0.jpg';
                        $this->ytb['url'] = $ytbID[0];
		}
		}
		
	}
	/*******************************************************************************/
	/* 
	/*******************************************************************************/
	function SetMetaValue() {
	
		if (count($this->img) != 0)
			$this->metaContentIMG = serialize($this->img);
		if (count($this->med) != 0)
			$this->metaContentMED = serialize($this->med);
		if (count($this->ytb) != 0)
			$this->metaContentYTB = serialize($this->ytb);
	}
	/*******************************************************************************/
	/* Applies filters from other plugins
	/*******************************************************************************/
	function apply_filters($content) {

		if (function_exists('ngg_addjs')) {
			include_once (NGGALLERY_ABSPATH."nggfunctions.php");
			$content = searchnggallerytags($content);
		}
		if (function_exists('pta_replace_tag')) $content = pta_replace_tag($content);
		if (function_exists('g2_imagebyidinpost')) $content = g2_imagebyidinpost($content);
		if (function_exists('g2_imagebypathinpost')) $content = g2_imagebypathinpost($content);

		return $content;

	}
}
?>
