<?php

if (stripos($_SERVER['REQUEST_URI'], 'post-thumb-options.php') !== false)
	require(PT_ABSPATH . 'lib/post-thumb-admin-functions.php');

################################################################################
########## Administration class
################################################################################
class PostThumbAdmin {

	// Version and path to check version
	var $PTRVERSION;

	var $settings;
	var $update_error = false;
	var $error_msg = '';
	var $testimg = 'images/test.jpg';

	var $BooleanList = array('safe_mode', 'rounded' , 'append', 'use_meta','use_png' ,'keep_ratio', 'max',
				'unsharp', 'use_catname', 'stream_check', 'hs_wordtube', 'wt_append', 'hs_youtube',
				'hs_use', 'effect', 'caption', 'tb_use', 'sb_use', 'hs_post', 'p_keep_ratio', 'p_max', 'p_rounded', 'p_use_png',
				'pt_replace', 'p_caption', 'wt_media', 'wt_playlist', 'ytb_media', 'p_rel', 'p_lightbox');

	var $OptionList = array('excerpt', 'excerptimg', 'excerpthref', 'linkto', 'append_text', 'resize_width', 'resize_height', 'wordtube_width', 'wordtube_height',
				'wordtube_pwidth', 'wordtube_pheight', 'wordtube_text', 'wordtube_vtext', 'wordtube_mtext', 
				'ovframe', 'hsframe', 'hs_width', 'hs_height', 'ovtopframe', 'unsharp_amount', 'unsharp_radius',
				'unsharp_threshold', 'corner_ratio', 'youtube_width', 'youtube_height',	'youtube_pwidth',
				'youtube_pheight', 'jpg_rate', 'png_rate', 'video_regex', 'bgcolor', 'hdcolor', 'ftcolor',
				'hsmargin', 'p_append_text', 'p_resize_width', 'p_resize_height', 'p_dirname', 'p_subfolder');
	
	/****************************************************************/
	/* Constructor
	/****************************************************************/
	function PostThumbAdmin() {
		global $wpdb;
			
		$this->settings = pt_GetStarterOptions();
		$this->PTRVERSION = PTRVERSION;

		// Header
		if ('deactivate' != $_GET['action'] && stripos($_SERVER['REQUEST_URI'], 'post-thumb-options.php') !== false) {
			add_action('admin_head', 'pt_admin_include_header');
		}

		// add WP actions - not limited to is_admin() to be applied also in case of xmlrpc posts by external blogging application
		add_action('publish_post',		array(&$this, 'savePostImage'));
		add_action('edit_post',			array(&$this, 'savePostImage'));
		add_action('save_post',			array(&$this, 'savePostImage'));
		add_action('wp_insert_post',		array(&$this, 'savePostImage'));

		// Plugin activation
		add_action('activate_post-thumb/post-thumb-options.php', array(&$this, 'activate'));

		// add option screen menu
		add_action('admin_menu', array(&$this, 'options'));
		
	}
	/****************************************************************/
	/* save post metadata
	/****************************************************************/
	function savePostImage($id) {
		$p = new pt_meta_thumbnail($id);
		$p->UpdateMeta();
		unset($p);
	}
	/****************************************************************/
	/* Plugin activation
	/****************************************************************/
	function activate() {
		$this->install(false);
	}
	/****************************************************************/
	/* Add post-thumb option
	/****************************************************************/
	function options() {

		if (function_exists('add_options_page'))
			add_options_page('Post Thumb Revisited', 'Post Thumb', 8, basename(__FILE__), array(&$this, 'MenuOptions'));

	}
	/****************************************************************/
	/* Installation routine
	/****************************************************************/
	function install($show_results=true) {

                $ptr2_options = pt_get_default_options();
		$ptr2_options['version'] = $this->PTRVERSION;
		update_option('post_thumbnail_settings', $ptr2_options);

	}
	/*******************************************************************************/
	/* Option panel
	/*******************************************************************************/
	function MenuOptions() {
	
		global $wpdb;

		// Init parameters
		$tmp_param = array();
	
		$pa = parse_url(SITEURL);
		$tmp_param['dn'] = str_replace($pa['path'],"",SITEURL);
		$bp = str_replace($pa['path'],"",str_replace( "\\", "/",ABSPATH));
		$tmp_param['bp'] = substr($bp, 0, strlen($bp)-1);
		$tmp_param['pa']['path'] = substr($pa['path'], 1, strlen($pa['path'])-1);

		// Detects wordTube
		$tmp_param['se'] = get_wordTubePath();
		if ($tmp_param['se'] == '') {
	        	$tmp_param['re']='';
	                $tmp_param['wdet']='';
		} else {
			$tmp_param['re'] = "MEDIA=";
	                $tmp_param['wdet']= __('Wordtube detected. Path: ', 'post-thumb-admin');
		}

		if (isset($_POST['info_update'])) {
			$this->RetrievePostOptions();
		}

		// Validates options & displays error message
		$this->ValidateOptions();
		if ($this->update_error || isset($_POST['info_update'])) {
			?>
	        	<div class="updated">
	    			<?php if ($this->update_error) : ?>
	    				<strong><?php _e('Update error:', 'post-thumb-admin'); ?></strong> <?php echo $this->error_msg; ?>
	    			<?php else : ?>
					<?php if (isset($_POST['info_update'])) { ?>
	    					<strong><?php _e('Settings saved', 'post-thumb-admin'); ?></strong>
	    				<?php } ?>
	    			<?php endif; ?>
	    		</div>
			<?php
		}
		
		// Init settings
		$this->settings = pt_get_default_options();
		update_option('post_thumbnail_settings',$this->settings);
		
		pt_MenuOptions($this->settings, $tmp_param);

	}
	/*******************************************************************************/
	/* Retrieve posted options
	/*******************************************************************************/
	function RetrievePostOptions() {
	
	  	if (ini_get('safe_mode')) $safe_mode = 'true'; else $safe_mode = 'false';

		$new_options = pt_get_default_options();

		$new_options['safe_mode'] = $safe_mode;
		$new_options['version']	= $this->PTRVERSION;
		$new_options['phpversion'] = phpversion();
		$new_options['wt_path'] = get_wordTubePath();

		if (isset($_POST['default_image']))
			$new_options['default_image'] = $this->noLeadSlash($this->noTrailSlash($_POST['default_image']));
		if (isset($_POST['full_domain_name']))
			$new_options['full_domain_name'] = $this->noTrailSlash($_POST['full_domain_name']);
		if (isset($_POST['base_path']))
			$new_options['base_path'] = $this->noTrailSlash($_POST['base_path']);
		if (isset($_POST['folder_name']))
			$new_options['folder_name'] = $this->noLeadSlash($this->noTrailSlash($_POST['folder_name']));
		if (isset($_POST['video_default']))
			$new_options['video_default'] = $this->noLeadSlash($this->noTrailSlash($_POST['video_default']));

		// Retrieve Boolean options
		if (isset($_POST['screen'])) {

			$blist = $this->BooleanList;
			
			foreach ($blist as $option) :
				$new_options[$option] = pt_GetBooleanOption ($_POST[$option]);
			endforeach;
		}

		// Retrieve other options
		foreach ($this->OptionList as $option) :
		  	if (isset($_POST[$option]))
				$new_options[$option] = $_POST[$option];
		endforeach;
		
		if (get_magic_quotes_gpc()) $_POST['video_regex'] = stripslashes($_POST['video_regex']);

		$this->settings = $new_options;
		update_option('post_thumbnail_settings',$new_options);

	}
	/****************************************************************/
	/* Validates update options
	/****************************************************************/
	function ValidateOptions() {

	        // Test resize values
		if (!is_numeric($this->settings['resize_width'])) {
	
			$this->isError(__("Resize width must be a number", 'post-thumb-admin'));
			$this->settings['resize_width'] = '60';
		}
		elseif (!is_numeric($this->settings['resize_height'])) {
			
			$this->isError(__("Resize width must be a number", 'post-thumb-admin'));
			$this->settings['resize_height'] = '60';
		}

	        // Test default image
		$video_exists = file_exists($this->settings['base_path'].'/'.$this->settings['video_default']);
		if (!$video_exists) $this->isError(__('Video default image not found on server.', 'post-thumb-admin'));

	        // Test default image
		$default_exists = file_exists($this->settings['base_path'].'/'.$this->settings['default_image']);
		if (!$default_exists) $this->isError(__('Default image not found on server.', 'post-thumb-admin'));

	        // Test folder name
		$this->TestFolder($this->settings['base_path'].'/'.$this->settings['folder_name']);
		
		// If no error, tries to generate test image
		if (!$this->is_error) {
			$testimg = PT_ABSPATH.$this->testimg;
			if (file_exists($testimg)) {
				$testthumb = GetAdminThumb($testimg);
				if (!$testthumb) {
					$this->isError(__("Cannot create test thumbnail.", 'post-thumb-admin'));
				}
			} else
				$this->isError(__("Test image doesn't exists.", 'post-thumb-admin'));
		}

	}
	/****************************************************************/
	/* Delete leading slash
	/****************************************************************/
	function noLeadSlash ($text) {
		
		if (substr($text, 0, 1) == '/') return substr($text, 1);
		return $text;
	}
	/****************************************************************/
	/* Delete trailing slash
	/****************************************************************/
	function noTrailSlash ($text) {
		
		if (substr($text, -1) == '/') return substr($text, 0, strlen($text)-1);
		return $text;
	}
	/****************************************************************/
	/* Test if a path is writable
	/****************************************************************/
	function isError ($text) {
		
		$this->update_error = true;
		$this->error_msg = $text;
	}
	/****************************************************************/
	/* Test if a path is writable
	/****************************************************************/
	function TestFolder ($is_writable_dir) {

		$rs = PT_ABSPATH . 'lib/index.htm';
		$rt = $is_writable_dir . '/index.htm';

		if (is_dir($is_writable_dir)) {
		
			if (@copy($rs, $rt)===false)

				$this->isError(__('Directory: ', 'post-thumb-admin').$is_writable_dir.' '.__('may not be writeable.', 'post-thumb-admin'));
			else
	                        unlink($rt);
		}
		else 
			$this->isError(__('Directory: ', 'post-thumb-admin').$is_writable_dir.' '.__('does not exist!', 'post-thumb-admin'));

	}
} // End of admin class

/****************************************************************/
/* Includes features in header for admin panel
/****************************************************************/
function pt_admin_include_header() {

	/* js includes ============================== */
	if (function_exists('wp_enqueue_script')) {
		echo "\n".'<!-- Start Of Script Generated By Post-Thumb Revisited Admin -->'."\n";
		// slider doesn't work with jQuery before 1.2 
		wp_deregister_script('jquery');
		wp_enqueue_script('jquery', PT_URLPATH.'js/jquery.js', false, '1.2.2');
		wp_enqueue_script('postthumb', PT_URLPATH.'js/post-thumb.js', array('jquery'));
		wp_print_scripts(array('jquery', 'postthumb'));
	} else {
		?>
		<script type="text/javascript" src="<?php echo PT_URLPATH; ?>js/jquery.js"></script>
		<script type="text/javascript" src="<?php echo PT_URLPATH; ?>js/post-thumb.js"></script>
		<?php
	}

	$echo = __('Click to hide and show', 'post-thumb-admin');

        ?>
	<link rel="stylesheet" href="<?php echo PT_URLPATH; ?>lib/ptr_admin.css" type="text/css" media="screen" />

	<script type="text/javascript">
	        var echo = "<?php echo $echo; ?>";
	</script>

	<?php
	echo '<!-- End Of Script Generated By Post-Thumb Revisited Admin -->'."\n";

}
/****************************************************************/
/* Loads language file at init
/****************************************************************/
function post_thumb_admin_init () {

	// Load language file
	$locale = get_locale();
	if ( !empty($locale) )
		load_textdomain('post-thumb-admin', PT_ABSPATH.'languages/' . 'post-thumb-admin'.$locale.'.mo');
}
add_action('init', 'post_thumb_admin_init');

?>
