<?php
/*
Plugin Name: Post Thumb Revisited
Plugin URI: http://www.alakhnor.com/post-thumb
Description: Thumbnails images from your posts. Useful for listing popular posts, post list, etc.
Version: 2.3
Author:  Alakhnor
Author URI: http://www.alakhnor.com/post-thumb

	Copyright (c) 2006 Victor Chang (http://theblemish.com) for Post Thumb
	Copyright (c) 2007 Alakhnor (http://www.alakhnor.com/post-thumb) for Post Thumb Revisited
	Post Thumb Revisited is released under the GNU General Public License (GPL)
	http://www.gnu.org/licenses/gpl.txt

	This is a WordPress 2 plugin (http://wordpress.org).
        Highslide JS is licensed under a Creative Commons Attribution-NonCommercial 2.5 License: http://creativecommons.org/licenses/by-nc/2.5/
*/

// Defines path & url constants
define('PT_PLUGIN_BASENAME', dirname(plugin_basename(__FILE__)));
define('SITEURL', get_settings('siteurl'));
define('UPLOAD_PATH', get_settings('upload_path'));
define('PT_ABSPATH', ABSPATH.'wp-content/plugins/' . PT_PLUGIN_BASENAME.'/');
define('PT_URLPATH', SITEURL.'/wp-content/plugins/' . PT_PLUGIN_BASENAME.'/');
define('PTRVERSION', '2.3');

// calls functions & class files
require(PT_ABSPATH . 'lib/post-thumb-functions.php');
require(PT_ABSPATH . 'lib/post-thumb-classes.php');
require(PT_ABSPATH . 'lib/post-thumb-image-editor.php');

$PTRevisited = new PostThumbRevisited();

################################################################################
########## MAIN CLASS
################################################################################
class PostThumbRevisited {

        var $settings;

	/**
	 * PostThumbRevisited
	 *
	 * Constructor for the PostThumbRevisited class.
	 */
	function PostThumbRevisited () {

		// Insert the menu and options
		add_option('post_thumbnail_settings','','Post Thumb Revisited Options');
		$this->settings = pt_GetStarterOptions();

		// defines constants
		define('POSTTHUMB_URLPATH', str_replace($this->settings['full_domain_name'], '/',SITEURL).'/wp-content/plugins/' . PT_PLUGIN_BASENAME.'/');
		define('POSTTHUMB_USE_HS', $this->settings['hs_use']=='true');

		// call classes
		if (POSTTHUMB_USE_HS) require(PT_ABSPATH . 'lib/post-thumb-highslide.php');

		if (stripos($_SERVER['REQUEST_URI'], 'wp-admin') !== false) {
			if (has_to_be_loaded()) {
				include ( PT_ABSPATH  . '/post-thumb-options.php' );
				$PTAdmin = new PostThumbAdmin();
			}
		}
		else {
			add_action('wp_head', array(&$this, 'include_header'));
			if (is_feed()) {
				$this->settings['hs_use']='false';
				$this->settings['tb_use']='false';
				$this->settings['hs_post']='true';
			}
		}

		add_filter('the_excerpt', array(&$this, 'excerpt'), 20);

	}
	/***********************************************************************************/
	/* Get thumbnail. Loop function.
	/***********************************************************************************/
	function GetPostData ($key) {
		$m = new pt_meta_thumbnail($key);
		$PostData = array();
		$PostData['img'] = unserialize($m->metaContentIMG);
		$PostData['med'] = unserialize($m->metaContentMED);
		$PostData['ytb'] = unserialize($m->metaContentYTB);
		unset($m);
		return $PostData;
	}
	/***********************************************************************************/
	/* Get thumbnail. Loop function.
	/***********************************************************************************/
	function GetThumb ($arg='') {
		global $post;

		$new_args = pt_parse_arg($arg);
		if (isset($new_args['OBJECT'])) $object = ($new_args['OBJECT']==1); else $object = false;

		setup_postdata($post);
		return $this->GetSingleThumb ($post->ID, $arg, $object);

	}
	/***********************************************************************************/
	/* Excerpt filter.
	/***********************************************************************************/
	function excerpt ($text) {
		global $post;

		$arg = 'myclasshref='.$this->settings['excerpthref'].'&myclassimg='.$this->settings['excerptimg'];
		if ($this->settings['excerpt']=='before')
			return $this->GetSingleThumb($post->ID, $arg).$text;
		elseif ($this->settings['excerpt']=='after')
			return $text.$this->GetSingleThumb($post->ID, $arg);
		return $text;
	}
	/***********************************************************************************/
	/* Prepares thumbnail for display.
	/***********************************************************************************/
	function GetSingleThumb ($ID, $arg='', $object=false) {

		$meta = $this->GetPostData($ID);

			$p = new pt_post_thumbnail( $meta, $arg);
			$post_link = $p->GetImgHTML();
			if ($object) {
				$post_obj = new PTObject($meta);
				$post_obj->thumb_url = $p->thumb_url;
				$post_obj->thumb_html = $post_link;
				$post_obj->ID = $ID;
				unset ($p);
				return $post_obj;
			}
			else {
				unset ($p);
				return $post_link;
			}

		return '';
	}

	/****************************************************************/
	/* test if a call is in a frame
	/****************************************************************/
	function is_inframe() {

		if (isset($_GET['inframe']))
			$inframe = $_GET['inframe'];
		else
			$inframe = 0;

		define('POSTHUMB_INFRAME', $inframe);

	}
	/****************************************************************/
	/* Includes features in header
	/****************************************************************/
	function include_header() {

		if (POSTTHUMB_USE_HS) {

			/* highslide includes ============================== */ 
			echo "\n".'<!-- Start Of Script Generated By Post-Thumb Revisited -->'."\n";
			wp_enqueue_script('highslide', PT_URLPATH.'js/highslide/highslide.js', false, '3.3.0');
			wp_enqueue_script('highslide-pt', PT_URLPATH.'js/highslide/highslide-pt.js', array('highslide'), '3.3.0');
			wp_enqueue_script('swfobject', PT_URLPATH.'js/highslide/swfobject.js', array('highslide'), '1.5');
          		wp_print_scripts(array('highslide', 'highslide-html', 'swfobject', 'highslide-pt'));
			echo '<!-- End Of Script Generated By Post-Thumb Revisited -->'."\n";

			if ($this->settings['ovtopframe'] == 'windows') { 
				define('CLOSETEXT', '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;');
				define('MOVETEXT', '&nbsp;');
				$styleMove = 'cursor: move; width: 100%; height: 20px; line-height: 100%; display: block;';
				$styleClose = 'position: absolute; width: 15px; background: url('.PT_URLPATH.'js/images/icon_close_link.gif) center center no-repeat; ';
			} else {
				define('CLOSETEXT', 'close');
				define('MOVETEXT', 'move');
				$styleMove = 'position: absolute; top: 2px; right: 50px;';
				$styleClose = 'position: absolute;';
			}

			?>
			<style type="text/css">
				.highslide-html-content { background-color: <?php echo $this->settings['bgcolor']; ?>; }
				.highslide-header { background-color: <?php echo $this->settings['hdcolor']; ?>; }
				.highslide-footer { background-color: <?php echo $this->settings['ftcolor']; ?>; }
				.highslide-close { <?php echo $styleClose; ?> }
				.highslide-move { <?php echo $styleMove; ?> }
				.highslide-dimming { background: black; position: absolute; visibility: hidden; }
			</style>
			<link rel="stylesheet" href="<?php echo PT_URLPATH; ?>js/style_hs.css" type="text/css" media="screen" />
			<script type="text/javascript">
				hs.graphicsDir = "<?php echo PT_URLPATH; ?>js/highslide/graphics/";
				hs.outlineType = "drop-shadow";
				hs.outlineWhileAnimating = false;
				hs.allowSizeReduction = true;
				hs.spaceForCaption = 30;
				hs.fullExpandTitle = "<?php _e('Expand to actual size', 'post-thumb'); ?>";
				hs.restoreTitle = "<?php _e('Click to close image, click and drag to move. Use arrow keys for next and previous.', 'post-thumb'); ?>";
				hs.focusTitle = "<?php _e('Click to bring to front', 'post-thumb'); ?>";
				hs.loadingText = "<?php _e('Loading...', 'post-thumb'); ?>";
				hs.loadingTitle = "<?php _e('Click to cancel', 'post-thumb'); ?>";
				hs.showCredits = false;
				hs.hideThumbOnExpand = false;
				hs.closeText = "<?php echo CLOSETEXT; ?>";
				hs.moveText = "<?php echo MOVETEXT; ?>";
			</script>

			<style type="text/css">
				.highslide-wrapper .highslide-html-content { min-height: 150px; }
				.highslide:hover img { cursor: url(<?php echo PT_URLPATH ?>js/highslide/graphics/zoomin.cur), pointer;}
				a.highslide, .highslide { cursor: url(<?php echo PT_URLPATH ?>js/highslide/graphics/zoomin.cur), pointer; outline: none; }
				.highslide-caption { display: none; }
				.highslide-loading { display: block; }
				.control { display: block; }
				.controlw { display: block; }
				.highslide-html-content { display: none; }
				.highslide-display-block { display: block; }
				.highslide-display-none { display: none; }
			</style>

			<?php
			$this->is_inframe();
		}
	}
}
// End of main class

/****************************************************************/
/* Includes library if required.
/****************************************************************/
if (get_pt_options('hs_post') == 'true') {
	require(PT_ABSPATH . 'lib/post-thumb-library.php');
}
/****************************************************************/
/* Loads language file at init
/****************************************************************/
function post_thumb_init () {

	// Load language file
	$locale = get_locale();
	if ( !empty($locale) )
		load_textdomain('post-thumb', PT_ABSPATH.'languages/' . 'post-thumb'.$locale.'.mo');
}
add_action('init', 'post_thumb_init');
/****************************************************************/
/* Class to return data
/****************************************************************/
class PTObject {

	var $ID;
	var $image;
	var $url;
	var $media_img;
	var $media_url;
	var $width;
	var $height;
	var $youtube_img;
	var $youtube_url;
	var $thumb_url='';
	var $thumb_html='';
	
	function PTObject ($meta) {
		global $post;
		
		$this->ID		= $post->ID;
		$this->image		= $meta['img']['img'];
		$this->url		= $meta['img']['url'];
		$this->media_img	= $meta['med']['img'];
		$this->media_url	= $meta['med']['url'];
		$this->width		= $meta['med']['width'];
		$this->height		= $meta['med']['height'];
		$this->youtube_img	= $meta['ytb']['img'];
		$this->youtube_url	= $meta['ytb']['url'];
		unset($meta);
	}
}
?>